==> aria2-1.7.2.tar.xz: aria2-1.7.2/src/DefaultBtMessageReceiver.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_DEFAULT_BT_MESSAGE_RECEIVER_H_
#define _D_DEFAULT_BT_MESSAGE_RECEIVER_H_

#include "BtMessageReceiver.h"

namespace aria2 {

class DownloadContext;
class Peer;
class PeerConnection;
class BtMessageDispatcher;
class BtMessageFactory;
class Logger;

class DefaultBtMessageReceiver : public BtMessageReceiver {
private:
  int32_t cuid;
  bool handshakeSent;
  SharedHandle<DownloadContext> _downloadContext;
  SharedHandle<Peer> peer;
  WeakHandle<PeerConnection> peerConnection;
  WeakHandle<BtMessageDispatcher> dispatcher;
  WeakHandle<BtMessageFactory> messageFactory;
  Logger* logger;

  void sendHandshake();
public:
  DefaultBtMessageReceiver();

  virtual ~DefaultBtMessageReceiver();

  virtual SharedHandle<BtHandshakeMessage> receiveHandshake(bool quickReply = false);

  virtual SharedHandle<BtHandshakeMessage> receiveAndSendHandshake();

  virtual SharedHandle<BtMessage> receiveMessage();

  void setCuid(int32_t cuid) {
    this->cuid = cuid;
  }

  int32_t getCuid() const {
    return cuid;
  }

  void setDownloadContext(const SharedHandle<DownloadContext>& downloadContext);

  void setPeer(const SharedHandle<Peer>& peer);

  void setPeerConnection(const WeakHandle<PeerConnection>& peerConnection);

  void setDispatcher(const WeakHandle<BtMessageDispatcher>& dispatcher);

  void setBtMessageFactory(const WeakHandle<BtMessageFactory>& factory);
};

typedef SharedHandle<DefaultBtMessageReceiver> DefaultBtMessageReceiverHandle;

} // namespace aria2

#endif // _D_DEFAULT_BT_MESSAGE_RECEIVER_H_

==> aria2-1.10.0.tar.xz: aria2-1.10.0/src/DefaultBtMessageReceiver.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_DEFAULT_BT_MESSAGE_RECEIVER_H_
#define _D_DEFAULT_BT_MESSAGE_RECEIVER_H_

#include "BtMessageReceiver.h"
#include "Command.h"

namespace aria2 {

class DownloadContext;
class Peer;
class PeerConnection;
class BtMessageDispatcher;
class BtMessageFactory;
class Logger;

class DefaultBtMessageReceiver : public BtMessageReceiver {
private:
  bool handshakeSent_;
  SharedHandle<DownloadContext> downloadContext_;
  WeakHandle<PeerConnection> peerConnection_;
  WeakHandle<BtMessageDispatcher> dispatcher_;
  WeakHandle<BtMessageFactory> messageFactory_;

  void sendHandshake();
public:
  DefaultBtMessageReceiver();

  virtual SharedHandle<BtHandshakeMessage> receiveHandshake
  (bool quickReply = false);

  virtual SharedHandle<BtHandshakeMessage> receiveAndSendHandshake();

  virtual SharedHandle<BtMessage> receiveMessage();

  void setDownloadContext(const SharedHandle<DownloadContext>& downloadContext);

  void setPeerConnection(const WeakHandle<PeerConnection>& peerConnection);

  void setDispatcher(const WeakHandle<BtMessageDispatcher>& dispatcher);

  void setBtMessageFactory(const WeakHandle<BtMessageFactory>& factory);
};

typedef SharedHandle<DefaultBtMessageReceiver> DefaultBtMessageReceiverHandle;

} // namespace aria2

#endif // _D_DEFAULT_BT_MESSAGE_RECEIVER_H_
